@@ -1,8 +1,8 @@
 
-__version__ = "0.11.2"
+__version__ = "0.11.3"
 __version_vcs_info__ = {
-    'branch': 'hotfix-0.11.2',
-    'revid': 'b67dde5',
-    'revno': 1918}
+    'branch': 'master',
+    'revid': '6e6d364',
+    'revno': 1922}
 __version_user_email__ = "saxtouri@admin.grnet.gr"
 __version_user_name__ = "Stavros Sachtouris"
